summaryrefslogtreecommitdiffstats
path: root/pym/_emerge/__init__.py
diff options
context:
space:
mode:
Diffstat (limited to 'pym/_emerge/__init__.py')
-rw-r--r--pym/_emerge/__init__.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/pym/_emerge/__init__.py b/pym/_emerge/__init__.py
index eae47628f..a7d397e9b 100644
--- a/pym/_emerge/__init__.py
+++ b/pym/_emerge/__init__.py
@@ -188,7 +188,7 @@ options=[
"--ask", "--alphabetical",
"--buildpkg", "--buildpkgonly",
"--changelog", "--columns",
-"--consistent",
+"--complete-graph",
"--debug", "--deep",
"--digest",
"--emptytree",
@@ -381,7 +381,7 @@ def create_depgraph_params(myopts, myaction):
myparams.discard("recurse")
if "--deep" in myopts:
myparams.add("deep")
- if "--consistent" in myopts:
+ if "--complete-graph" in myopts:
myparams.add("consistent")
return myparams
@@ -2842,7 +2842,7 @@ class depgraph(object):
intially satisfied.
Since this method can consume enough time to disturb users, it is
currently only enabled by the --consistent option.
"""
if "consistent" not in self.myparams:
# Skip this to avoid consuming enough time to disturb users.
@@ -2842,7 +2842,7 @@ class depgraph(object):
intially satisfied.
Since this method can consume enough time to disturb users, it is
- currently only enabled by the --consistent option.
+ currently only enabled by the --complete-graph option.
"""
if "consistent" not in self.myparams: